=======
Podenco
=======


.. image:: https://img.shields.io/pypi/v/podenco.svg
        :target: https://pypi.python.org/pypi/podenco

.. image:: https://img.shields.io/travis/cristobalcl/podenco.svg
        :target: https://travis-ci.org/cristobalcl/podenco

.. image:: https://codecov.io/gh/cristobalcl/podenco/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/cristobalcl/podenco

.. image:: https://readthedocs.org/projects/podenco/badge/?version=latest
        :target: https://podenco.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Static podcast generator.

Work in progress.


* Free software: MIT license
* Documentation: https://podenco.readthedocs.io.


Credits
-------

* Cristóbal Carnero Liñán - http://cristob.al
